/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#include "../source/codegen_source_base.h"

namespace tvm {
namespace runtime {

ffi::Module HexagonModuleCreate(std::string data, std::string fmt,
                                std::unordered_map<std::string, FunctionInfo> fmap,
                                std::string asm_str, std::string obj_str, std::string ir_str,
                                std::string bc_str) {
  LOG(WARNING) << "Hexagon runtime is not enabled, return a source module...";
  return codegen::DeviceSourceModuleCreate(data, fmt, fmap, "hex");
}

}  // namespace runtime
}  // namespace tvm
